AgentEvent

Struct AgentEvent 

pub struct AgentEvent {
Show 13 fields pub event_id: String, pub occurred_at: DateTime<Utc>, pub device: DeviceContext, pub agent: AgentContext, pub session_id: String, pub turn_index: NonZeroU32, pub llm: LlmContext, pub side: AgentEventSide, pub text: Option<String>, pub token_usage: TokenUsage, pub tool_calls: Vec<ToolCall>, pub tool_results: Vec<ToolResult>, pub attachments: Vec<ImageAttachment>,
}
One event decoded with the contract defined by the active plugin protocol.

Fields

event_id: String

Stable event identifier assigned by the event producer.

occurred_at: DateTime<Utc>

Time at which the broker observed the logical event.

device: DeviceContext

Device context observed by the broker.

agent: AgentContext

Agent product context inferred from traffic.

session_id: String

Provider or collector session identifier.

turn_index: NonZeroU32

One-based collector turn index within the session.

llm: LlmContext

Provider and model context.

side: AgentEventSide

Request or response side represented by this event.

text: Option<String>

Policy-retained request or response text.

token_usage: TokenUsage

Token counters attributed to this event side.

tool_calls: Vec<ToolCall>

Normalized tool calls associated with this event side.

tool_results: Vec<ToolResult>

Normalized tool results associated with this event side.

attachments: Vec<ImageAttachment>

Policy-retained image attachments.