Module message

Module message 

Handshake and broker control wire payloads for plugin protocol version 1.

Structs

BrokerClose
Deliberate final frame sent before the broker closes an accepted session.
BrokerError
Handshake rejection sent as the broker’s first response frame.
BrokerHello
Handshake response sent from abyss-broker to one plugin process.
PluginHello
Initial handshake sent from a plugin process to abyss-broker.
UnsupportedPluginProtocolVersion
An unsupported broker plugin protocol version received from the wire.

Enums

BrokerCloseCode
Stable deliberate-close meanings defined by protocol version 1.
BrokerErrorCode
Stable handshake rejection meanings defined by protocol version 1.
PluginProtocolVersion
Broker plugin protocol versions supported by this SDK release.