#[non_exhaustive]pub enum BrokerErrorCode {
UnsupportedProtocolVersion,
InvalidHandshake,
ResourceLimit,
}Expand description
Stable handshake rejection meanings defined by protocol version 1.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedProtocolVersion
The requested protocol version is not supported.
InvalidHandshake
The first frame is malformed or contains an invalid plugin identifier.
ResourceLimit
The broker cannot accept another plugin session.
Implementations
Sourceimpl BrokerErrorCode
impl BrokerErrorCode
Sourcepub const fn wire_value(self) -> u32
pub const fn wire_value(self) -> u32
Returns the integer carried in a BrokerError frame.