Handshake and broker control wire payloads for plugin protocol version 1.
Structs
- Broker
Close - Deliberate final frame sent before the broker closes an accepted session.
- Broker
Error - Handshake rejection sent as the broker’s first response frame.
- Broker
Hello - Handshake response sent from
abyss-brokerto one plugin process. - Plugin
Hello - Initial handshake sent from a plugin process to
abyss-broker. - Unsupported
Plugin Protocol Version - An unsupported broker plugin protocol version received from the wire.
Enums
- Broker
Close Code - Stable deliberate-close meanings defined by protocol version 1.
- Broker
Error Code - Stable handshake rejection meanings defined by protocol version 1.
- Plugin
Protocol Version - Broker plugin protocol versions supported by this SDK release.